@@ -1,5 +1,5 @@
 /*
- * SpanDSP - a series of DSP components for telephony
+ * VoIPcodecs - a series of DSP components for telephony
  *
  * lpc10_voicing.c - LPC10 low bit rate speech codec.
  *
@@ -251,6 +251,9 @@ void lpc10_voicing(lpc10_encode_state_t *s,
     int32_t lbe;
     float snr2;
 
+#if (_MSC_VER >= 1400) 
+    __analysis_assume(half >= 0  &&  half < 2);
+#endif
     inbuf_offset = 0;
     lpbuf_offset = 0;
     if (inbuf)
